var textEdit = new Vue({
  el: '#text_edit',
  template:
`
<div>
	<div class="modal-header">
		<button type="button" class="close" data-dismiss="modal"><span aria-hidden="true">&times;</span><span class="sr-only">Закрыть</span></button>
		<h4 class="modal-title">{{ title }}</h4>
	</div>
	<div class="modal-body" style="padding: 10px;">
		<div v-show="!loading" class="dropdown" style="display:inline-block; font-size:14px; margin-bottom: 10px; margin-right: 10px;">
			<a class="dropdown-toggle btn btn-white" data-toggle="dropdown" href="#">
				Кодировка: {{ encoding }}
			</a>
			<ul class="dropdown-menu dropdown-user" style="font-size:14px;">
				<li>
					<a v-on:click="reload('utf-8')">utf-8</a>		
				</li>
				<li>
					<a v-on:click="reload('windows-1251')">windows-1251</a>
				</li>
				<li>
					<a v-on:click="reload('cp866')">cp866 (DOS)</a>
				</li>
			</ul>
		</div>
		<div v-show="!loading" class="pull-right" style="display:inline-block; font-size:14px; margin-bottom: 10px;">
			<a v-on:click="download(link)" class="btn btn-white">Скачать</a>		
		</div>
		<div v-show="!edit && !loading" class="pull-right" style="display:inline-block; font-size:14px; margin-bottom: 10px; margin-right: 10px;">
			<a v-on:click="edit=true;" class="btn btn-white">Редактировать</a>
		</div>
		<div v-if="loading" class="sk-spinner sk-spinner-three-bounce">
			<div class="sk-bounce1"></div>
			<div class="sk-bounce2"></div>
			<div class="sk-bounce3"></div>
		</div>						
		<textarea v-else id="text_area" class="animated fadeInDown" style="width: 100%; height: 500px; font-family: monospace; color: black;" v-bind:readonly="!edit" v-model="text"></textarea>
	</div>

	<div v-show="!loading" class="modal-footer">
		<button v-show="edit" v-on:click="save(link)" type="button" class="btn btn-warning">Сохранить</button>
		<button type="button" class="btn btn-primary" data-dismiss="modal">Закрыть</button>
	</div>
</div>
`,
  data() {
    return {
		text: 'text',
		title: 'title',
		loading: false,
		link: '',
		edit: false,
		encoding: 'utf-8'
    };
  },
  mounted() {
	  //this.refresh();
  },
  methods: {
    load: function (name,link) {
		this.loading = true;
		this.link = link;
		this.title = name;
		this.edit = false;
		axios
		  .get('api/get_text_file?encoding=' + this.encoding + '&file=' + link)
		  .then(response => {
			  this.text = response.data;
			  this.loading = false;
		  })
		  .catch(error => console.log(error));		
	},
	reload(encoding) {
		this.encoding = encoding;
		this.load(this.title,this.link);
	},	
    download: function (file) {
		window.location.href = 'api/download?file=' + file;
    },
    save: function (file) {
		var data = new FormData();
		data.append(file, this.text);		
		axios.post('api/upload_files', data,
			{
                headers: {
                    'Content-Type': 'multipart/form-data',
					'Content-Disposition': 'attachment;',
					'Text-Enconding': this.encoding,
				}
			})
			.then(function (res) {
			  //output.className = 'container';
			  //output.innerHTML = res.data;
			})
			.catch(error => console.log(error));		
	}
  }  
});	